/*
 * Copyright 2012 Peter W Leong
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

package biz.freshcode.b_generation;

import java.util.List;

import static java.lang.Character.toLowerCase;

public class BgenStringUtil {
    public static boolean isBlank(String st) {
        return st.length() == 0;
    }

    /**
     * Joins the two strings together using the separator.  If either is empty then the separator is not used.
     */
    public static String join(String left, String sep, String right) {
        if (isBlank(left)) return right;
        if (isBlank(right)) return left;
        return left + sep + right;
    }

    /**
     * Joins the given list of strings together using the given separator.
     */
    public static String join(List<String> ss, String sep) {
        StringBuilder sb = new StringBuilder();
        for (String s : ss) {
            if (sb.length() > 0) sb.append(sep);
            sb.append(s);
        }
        return sb.toString();
    }

    public static String decapitalize(String simpleName) {
        if (isBlank(simpleName)) return "";
        return toLowerCase(simpleName.charAt(0)) + simpleName.substring(1);
    }
}
