/*
 * Copyright 2012 Peter W Leong
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

package biz.freshcode.b_generation;

import java.util.LinkedHashMap;
import java.util.Map;

import static biz.freshcode.b_generation.BgenStringUtil.isBlank;

/**
 * Maps from one package to another.
 */
public class PackageMapper {
    private Map<String, String> mapper = new LinkedHashMap<String, String>();

    /**
     * Sets up a mapping from one package prefix to another.
     * These are traversed in the same order added.  Add a "" mapping to catch all.
     */
    public void addMapping(String from, String to) {
        mapper.put(from, to);
    }


    public String calcPkgFor(Class beanCls) {
        String origPkg = beanCls.getPackage().getName();
        for (String from : mapper.keySet()) {
            String to = mapper.get(from);
            if (isBlank(from)) {
                // the catch all
                if (isBlank(to)) return origPkg;
                return to + "." + origPkg;
            } else if (origPkg.equals(from)) {
                // same package
                return to;
            } else if (origPkg.startsWith(from + ".")) {
                // found a mapping
                return to + origPkg.substring(from.length());
            }
        }
        // This is likely a symptom of mis-configuration.
        throw new IllegalArgumentException("Unable to find a package mapping for " + beanCls.getName());
    }
}
