/*
 * Copyright 2012 Peter W Leong
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

package biz.freshcode.b_generation.demo;

import java.util.Date;

import static java.util.Arrays.asList;

/**
 * Illustrates the use of a builder.
 */
public class BgenDemoBuilderUsage {
    public BgenDemo create() {
        // TIP: For complex config don't instantiate the inner element here
        Date chainArg;

        BgenDemo<String> bean = new BgenDemoBuilder<String>()

                .addChain(9L)
//               TIP: Instantiate here so that config remains together
                .addChainAlt(chainArg = new Date(0L))
                .addSimple(99)

                .str("Bruce")
                .varArgs(0, 1, 2)
                .arr(new String[]{"a", "b", "c"})

//                Generics example
                .generic(asList("Lee"), false, "Rocks")

//                Loops can be introduced with a custom parent class
                .construct(new BgenDemoConstruct<BgenDemoBuilder<String>>() {
                    public void run() {
                        for (int i = 0; i < 10; i++) {
                            //... elaborate setup ...
                            builder.addSimple(i);
                        }
                    }
                })

                .bgenDemo;

        // TIP: Continue configuration here like adding handlers to buttons etc.
        chainArg.setTime(60000L);

        return bean;
    }
}
